<?php
/*  USAGE
 *  on appelle la function au sein d'une balise img :
 *  <img src="<?php echo auto_thumb('nom.jpg', largeur, hauteur); ?>" />
 *  ou en la générant 
 *  $balise="<img src='".auto_thumb('nom.jpg',139,139)."' alt='nom.jpg' class='lightbox'/>";
*/




/**
 *   Génère automatiquement la miniatures de l'image passée en argument
 *   aux dimensions spécifiées ou par défaut (100px)
 *   Les miniatures ne sont créées que si elles n'existent pas encore;
 *   si elles existent, seul le chemin est renvoyé.
 *
 * @author bronco@warriordudimanche.com
 * @copyright open source and free to adapt (keep me aware !)
 * @version 2.0
 * @param string $img chemin vers le fichier image
 * @param integer $width largeur maximum du thumbnail généré
 * @param integer $height hauteur maximum du thumbnail généré
 * @param string $add_to_thumb_filename suffixe à ajouter au fichier thumbnail
 * @param boolean $crop_image true=redimensionne et recadre l'image aux dimensions width/$height, false, redimensionne avec proportions
*/
function auto_thumb($img,$width=null,$height=null,$add_to_thumb_filename='_THUMB_',$crop_image=false){
    // initialisation
    $DEFAULT_WIDTH='100';
    $DEFAULT_HEIGHT='100';
    $DONT_RESIZE_THUMBS=true;

    if (!$width){$width=$DEFAULT_WIDTH;}
    if (!$height){$height=$DEFAULT_HEIGHT;}
    $recadrageX=0;$recadrageY=0;
    $motif='#\.(jpe?g|png|gif)#i'; // Merci à JéromeJ pour la correction  ! 
    $rempl=$add_to_thumb_filename.'_'.$width.'x'.$height.'.$1';
    $thumb_name=preg_replace($motif,$rempl,$img);
    // sortie prématurée:
    if (!file_exists($img)){return 'auto_thumb ERROR: '.$img.' doesn\'t exists';}
    if (file_exists($thumb_name)){return $thumb_name;} // miniature déjà créée
    if ($add_to_thumb_filename!='' && preg_match($add_to_thumb_filename,$img) && $DONT_RESIZE_THUMBS){return false;} // on cherche à traiter un fichier miniature (rangez un peu !)

    // redimensionnement en fonction du ratio
    $taille = getimagesize($img);
    $src_width=$taille[0];
    $src_height=$taille[1];
    if (!$crop_image){ 
        // sans recadrage: on conserve les proportions
        if ($src_width<$src_height){
            // portrait
            $ratio=$src_height/$src_width;
            $width=$height/$ratio;
        }else if ($src_width>$src_height){
            // paysage
            $ratio=$src_width/$src_height;
            $height=$width/$ratio;
        }
    }else{
        // avec recadrage: on produit une image aux dimensions définies mais coupée
        if ($src_width<$src_height){
            // portrait
            $recadrageY=round(($src_height-$src_width)/2);
            $src_height=$src_width;
        }else if ($src_width>$src_height){
            // paysage
            $recadrageX=round(($src_width-$src_height)/2);
            $src_width=$src_height;
        }
    }



    // en fonction de l'extension
    $fichier = pathinfo($img);
    $extension=str_ireplace('jpg','jpeg',$fichier['extension']);
    
    
    $fonction='imagecreatefrom'.strtolower($extension);
    $src  = $fonction($img);  // que c'est pratique ça ^^ !
    
    // création image
    $thumb = imagecreatetruecolor($width,$height);
    
    // gestion de la transparence 
    // (voir fonction de Seebz: http://code.seebz.net/p/imagethumb/)
    if( $extension=='png' ){imagealphablending($thumb,false);imagesavealpha($thumb,true);}
    if( $extension=='gif'  && @imagecolortransparent($img)>=0 ){
        $transparent_index = @imagecolortransparent($img);
        $transparent_color = @imagecolorsforindex($img, $transparent_index);
        $transparent_index = imagecolorallocate($thumb, $transparent_color['red'], $transparent_color['green'], $transparent_color['blue']);
        imagefill($thumb, 0, 0, $transparent_index);
        imagecolortransparent($thumb, $transparent_index);
    }
    
    imagecopyresampled($thumb,$src,0,0,$recadrageX,$recadrageY,$width,$height,$src_width,$src_height);
    imagepng($thumb, $thumb_name);
    imagedestroy($thumb);
    
    return $thumb_name;
}
/**
 * Ajoute le style associé à l'affichage des émoticones et des galeries
 * @param $width int la largeur d'une image dans la galerie
 * @param $diviseur int le diviseur permettant la génération des fausses miniatures
 * @param $allow_com boll affiche le style associé aux émoticons si les commentaires sont autorisés
 *
 * @author Cyril MAGUIRE
 */
function auto_style($path=null,$width=100,$diviseur=1,$add=false,$allow_com=false) {

	$end = '
            div,div:hover{transition: all 300ms;}
            @media (max-width: 768px) {
                div.galerie{width:300px;}
            }';

    $galerie = '
            div.galerie.g'.$width.'_'.$diviseur.' div.photo{width:'.($width/$diviseur).'px;margin:5px;padding:5px;display:inline-block;border-radius:3px;border: 1px solid #ccc;-webkit-box-shadow: 8px 8px 2px -3px rgba(50, 50, 50, 0.75);-moz-box-shadow:8px 8px 2px -3px rgba(50, 50, 50, 0.75);box-shadow:8px 8px 2px -3px rgba(50, 50, 50, 0.75); }
            @media (min-width: 768px) {
               div.galerie.g'.$width.'_'.$diviseur.' div.photo:hover{z-index:9999999;padding:0;transform:scale('.$diviseur.','.$diviseur.');-webkit-transform:scale('.$diviseur.','.$diviseur.');-moz-transform:scale('.$diviseur.','.$diviseur.'),-o-transform:scale('.$diviseur.','.$diviseur.'); }
            }
        ';

	$emoticons = '
		img.smile {
	        vertical-align: -9px;
	        width: 34px;
	        height: auto;
	        border:none;
	    }
	    .list_emotes img, .addspoiler {cursor:pointer;} 
	    .list_emotes strong, .list_emotes .spoiler {
		    display: none;
		}
		blockquote .spoiler {
		    opacity: 0.1;
		    color: transparent;
		    cursor: pointer;
		    display: inline-block;
		}
		blockquote .spoiler:active{
			opacity: .99;
			filter: alpha(opacity=99);
			-ms-filter: "alpha(opacity=99)"; 
			-khtml-opacity: .99; 
			-moz-opacity: .99;  
			color:inherit;
		}
		';

	$css = ($add==false ? $emoticons.'
	    div.galerie {margin:20px auto;width:600px;text-align:center;}
	    div.photo img{opacity:0.8}
	    div.photo:hover img{opacity:1}'.$end : file_get_contents($path))
	;
	if (strpos($css, 'img.smile') === false && $allow_com) { 
		$css = $emoticons.$css; 
	}
	if ($add && strpos($css, 'g'.$width.'_'.$diviseur) === false) { $css = str_replace($end,$galerie.$end,$css);}
	if (!$allow_com) { $css = str_replace($emoticons,'',$css); }
    return $css.'
';
}
// Ajout du paramètre $diviseur
function auto_galerie($path=null,$title=null,$width=100,$height=100,$diviseur=1,$crop=false,$infos=false,$style=false){
    $plxMotor = plxMotor::getInstance();
    $diviseur = (int) $diviseur;
    if ($diviseur <= 0) $diviseur = 1;
    if (!$path){return false;}
    $liste=array_merge(glob($path.'/*.png'),glob($path.'/*.gif'),glob($path.'/*.jpg'),glob($path.'/*.jpeg'));
    if (!$liste) {
        $liste=globDir($path.'/');
    }
    $thumb_name='_THUMB_';$crop_name='_CROPPED_';$prop_name='_PROPORTION_';
    $return = '';
    if (!empty($liste)){
        $return .=  '
        <div class="galerie g'.$width.'_'.$diviseur.'">';
        if ($title){$return .= '<h1 class="title">'.$title.'</h1>';}
                
                    foreach($liste as $image){
                        $image = str_replace('./data','data',$image);
                        $i=basename($image);
                        if (stripos($i,$thumb_name)===false&&stripos($i,$crop_name)===false&&stripos($i,$prop_name)===false){             
                            $return .=  '
                            <div class="photo">
                                <a href="'.$plxMotor->urlRewrite($image).'" onclick="window.open(this.href);return false;"><img src="'.$plxMotor->urlRewrite(auto_thumb($image,$width,$height,'_THUMB_',$crop)).'" /></a>';
                                if ($infos==true){
                                    $return .=  '<div class="infos">';
                                    $return .=  '<div class="nom">'.basename($image).'</div>';
                                    $taille=round(filesize($image)/1000,1);
                                    
                                    $return .=  '<div class="taille">'.$taille.' Ko</div>';
                                    $return .=  '</div>';
                                }
                            $return .=  '
                            </div>
                            ';
                        }
                    }
        
        $return .=  '
            <div style="clear:both"></div>
        </div>';
 
    }else{
        // $return .=  '<p class="error">Pas d\'images dans <em>'.$path.'</em></p>';
    }
    return $return;
}
/**
 * Fonction listant le contenu d'un dossier et qui ne retourne que les fichiers dont les extensions sont autorisées
 *
 * @param $path string le chemin absolu vers le dossier à traiter
 * @return $liste array un tableau contenant le chemin vers les fichiers dont l'extension est valide
 *
 * @author Cyril MAGUIRE
 */
function globDir($path) {
    $liste =  array();
    $extensions = array('jpg','jpeg','gif','png','bmp','JPG','JPEG','GIF','PNG','BMP');
    if ($handle = opendir($path)) {
        while (false !== ($file = readdir($handle))) {
            if(in_array(substr($file, strrpos($file, '.')+1), $extensions)) {
                $liste[] = $path.$file;
            }
        }
        closedir($handle);
    }
    if (!empty($liste)) {
        return $liste;
    } else {
        return false;
    }
}

function vignettage($content) {
    $plxMotor = plxMotor::getInstance();
    switch ($plxMotor->mode) {
        case 'home':
        case 'categorie':
        	$count = 0;
            $return = preg_replace('!<p>(<img(.*)?src="(.*)\.(jpg|jpeg|png|gif)" alt="(.*(?:^data-spxtynimce="true")?)" (width="([0-9]*)" height="([0-9]*)")?(.*)?\/>)!i', '<div class="vignette"><img src="$3.$4" alt="" /></div><div class="wrap-art"><p>', $content,-1,$count);
            if ($count>0) {
            	$return = str_replace('</article>', '</div><!--Fin wrap-art --></article>',$return);
            }
            break;
        case 'article':
        case 'preview':
        	$count = 0;
            $return = preg_replace('!<p>(<img(.*)?(src="(.*)\.(jpg|jpeg|png|gif)" alt="(.*)") (width="([0-9]*)" height="([0-9]*)")?(.*)?\/>)!i', '<div class="vignette"><img $3 /></div><div class="wrap-art"><p>', $content,-1,$count);
            if ($count>0) {
            	$return = str_replace('</article>', '</div><!--Fin wrap-art --></article>',$return);
            }
            break;
        
        default:
            # code...
            break;
    }
    if (isset($return)) {
    	return $return;
    } else {
    	return $content;
    }
    
}
?>